@@ -30,7 +30,7 @@ use CGI;
 #use Apache2::RequestUtil;
 #use Apache2::Const -compile => qw(:http);
 
-our $VERSION = q[472.0.3];
+our $VERSION = q[473.0.1];
 our $CRUD    = {
 		POST   => 'create',
 		GET    => 'read',
@@ -54,6 +54,8 @@ sub accept_extensions {
 	  {'.html' => q[]},
 	  {'.xml'  => q[_xml]},
 	  {'.png'  => q[_png]},
+	  {'.svg'  => q[_svg]},
+	  {'.svgz' => q[_svgz]},
 	  {'.jpg'  => q[_jpg]},
 	  {'.rss'  => q[_rss]},
 	  {'.atom' => q[_atom]},
