@@ -23,8 +23,9 @@ use HTML::Entities qw(encode_entities_numeric);
 use XML::Simple qw(XMLin);
 use utf8;
 use ClearPress::Localize;
+use MIME::Base64 qw(encode_base64);
 
-our $VERSION = q[472.0.3];
+our $VERSION = q[473.0.1];
 our $DEBUG_OUTPUT   = 0;
 our $TEMPLATE_CACHE = {};
 our $LEXICON_CACHE  = {};
@@ -48,7 +49,9 @@ sub new {
   my $aspect = $self->aspect || q[];
 
   $self->{content_type} ||= ($aspect =~ /(?:rss|atom|ajax|xml)$/smx)?'text/xml':q[];
-  $self->{content_type} ||= ($aspect =~ /(?:js|json)$/smx)?'application/javascript':q[];
+  $self->{content_type} ||= ($aspect =~ /(?:js|json)$/smx)?'application/json':q[];
+  $self->{content_type} ||= ($aspect =~ /_svg$/smx)?'image/svg+xml':q[];
+  $self->{content_type} ||= ($aspect =~ /_svgz$/smx)?'image/svg+xml':q[];
   $self->{content_type} ||= ($aspect =~ /_png$/smx)?'image/png':q[];
   $self->{content_type} ||= ($aspect =~ /_jpg$/smx)?'image/jpeg':q[];
   $self->{content_type} ||= ($aspect =~ /_txt$/smx)?'text/plain':q[];
@@ -89,6 +92,14 @@ sub setup_filters {
                          return encode_entities_numeric($string),
                        });
 
+  $self->add_tt_filter('base64', sub {
+                         my $string = shift;
+                         if(!defined $string) {
+                           $string = q[];
+                         }
+                         return encode_base64($string),
+                       });
+
   my $util = $self->util;
 
   $self->add_tt_filter('loc', [sub {
@@ -284,7 +295,7 @@ sub render {
   }
 
   if($self->can($method)) {
-    if($aspect =~ /_(?:jpg|png|gif)/smx) {
+    if($aspect =~ /_(?:jpg|png|gif|svg|svgz)/smx) {
       return $self->$method();
     }
 
@@ -623,7 +634,7 @@ sub decor {
   my $self = shift;
   my $aspect = $self->aspect || q[];
 
-  if($aspect =~ /(?:rss|atom|ajax|xml|json|js|_png|_jpg|_txt)$/smx) {
+  if($aspect =~ /(?:rss|atom|ajax|xml|json|js|_png|_jpg|_svg|_svgz|_txt)$/smx) {
     return 0;
   }
   return 1;
@@ -687,6 +698,34 @@ sub actions {
   return $content;
 }
 
+sub redirect {
+  my ($self, $internal_uri, $status) = @_;
+
+  #########
+  # compile special pieces of mod-perl if not already compiled
+  #
+  for my $pkg (qw(Apache2::RequestRec Apache2::SubRequest)) {
+    my $ns = "$pkg::";
+    no strict 'refs'; ## no critic (ProhibitNoStrict)
+    if(!scalar %{$ns}) {
+      require $pkg;
+      $pkg->import();
+    }
+  }
+
+  my $cgi = $self->util->cgi;
+  my $r   = $cgi->r;
+  if($r) {
+    $r->status($status || '301');
+
+    return $r->redirect($internal_uri);
+  }
+
+  carp q[Redirect support unavailable. Please request it via CPAN RT.];
+
+  return;
+}
+
 # todo: auto-create these <action>_<format> style accessors
 
 sub list_xml {
@@ -958,6 +997,12 @@ e.g.
 
   my $sActionOutput = $oView->actions;
 
+=head2 redirect - Apache internal redirect via mod-perl subrequest
+
+  $oView->redirect($sURL);
+
+  $oView->redirect($sURL, $sStatus); # optional status
+
 =head2 list_xml - default passthrough to list for xml service
 
 =head2 read_xml - default passthrough to read for xml service
